<?php
/**
 * $Horde: genie/item.php,v 1.30 2005/01/03 14:34:50 jan Exp $
 *
 * Copyright 2003-2005 Chuck Hagenbuch <chuck@horde.org>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */

@define('GENIE_BASE', dirname(__FILE__));
require_once GENIE_BASE . '/lib/base.php';
require_once 'Horde/Prefs/CategoryManager.php';
$cManager = &new Prefs_CategoryManager();

/* Redirect to the wishlist if no action has been requested. */
$actionID = Util::getFormData('actionID');
if (is_null($actionID)) {
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
}

/* Run through the action handlers. */
switch ($actionID) {
case GENIE_ADD_ITEM:
    /* Set up the item attributes. */
    $wishlist_id = Genie::getDefaultWishlist(PERMS_EDIT);
    $item_id = null;
    $item_quantity = 1;
    $item_price = '';
    $item_prodid = '';
    $item_prodid_type = 'other';
    $item_vendors = '';
    $item_name = '';
    $item_desc = '';
    $item_purchased = 0;
    $item_category = '';

    $title = _("Add A New Item");
    $notification->push('document.item.item_name.focus();', 'javascript');
    break;

case GENIE_MODIFY_ITEM:
    $item_id = Util::getFormData('item');
    $wishlist_id = Util::getFormData('wishlist');
    $item = Genie::getItem($wishlist_id, $item_id);

    if ($item) {
        /* Set up the item attributes. */
        $item_name = $item['name'];
        $item_desc = $item['desc'];
        $item_price = $item['price'];
        $item_quantity = $item['quantity'];
        $item_purchased = $item['purchased'];
        $item_category = $item['category'];
        $item_prodid = $item['prodid'];
        $item_prodid_type = $item['prodid_type'];
        $item_vendors = $item['vendors'];

        $title = sprintf(_("Modifying %s"), $item_name);
    } else {
        $title = _("Unknown item");
    }
    break;

case GENIE_SAVE_ITEM:
    /* Get the form values. */
    $item_id = Util::getFormData('item');
    $wishlist_original = Util::getFormData('wishlist_original');
    $wishlist_target = Util::getFormData('wishlist_target');

    $share = $genie_shares->getShare($wishlist_target);
    if (is_a($share, 'PEAR_Error')) {
        $notification->push(sprintf(_("Access denied saving item: %s"),
                                    $share->getMessage()), 'horde.error');
    } elseif (!$share->hasPermission(Auth::getAuth(), PERMS_EDIT)) {
        $notification->push(sprintf(_("Access denied saving item to %s"),
                                    $share->get('name')), 'horde.error');
    } else {
        $item_name = Util::getFormData('item_name');
        $item_desc = Util::getFormData('item_desc');
        $item_purchased = Util::getFormData('item_purchased');
        $item_category = Util::getFormData('item_category');
        $item_quantity = Util::getFormData('item_quantity');
        $item_price = Util::getFormData('item_price');
        $item_prodid = Util::getFormData('item_prodid');
        $item_prodid_type = Util::getFormData('item_prodid_type');
        $item_vendors = Util::getFormData('item_vendors');

        if ($new_category = Util::getFormData('new_category')) {
            $new_category = $cManager->add($new_category);
            if ($new_category) {
                $item_category = $new_category;
            }
        }

        /* If $item_id is set, we're modifying an existing
         * item. Otherwise, we're adding a new item with the provided
         * attributes. */
        if (!empty($item_id) && !empty($wishlist_original)) {
            if ($wishlist_original != $wishlist_target) {
                /* Saving to a different wishlist */
                $share = $genie_shares->getShare($wishlist_original);
                if (!is_a($share, 'PEAR_Error') &&
                    $share->hasPermission(Auth::getAuth(), PERMS_DELETE)) {
                    $storage = &Genie_Driver::singleton($wishlist_original);
                    $result = $storage->deleteItem($item_id);
                    if (is_a($result, 'PEAR_Error')) {
                        $notification->push(sprintf(_("There was a problem removing the item from %s: %s"),
                                                    $share->get('name'),
                                                    $result->getMessage()), 'horde.error');
                    }
                } else {
                    $notification->push(sprintf(_("Access denied removing item from %s."),
                                                $share->get('name')), 'horde.error');
                }

                $storage = &Genie_Driver::singleton($wishlist_target);
                $result = $storage->add($item_name, $item_desc, $item_quantity,
                                        $item_price, $item_prodid,
                                        $item_prodid_type, $item_vendors,
                                        $item_category, $item_purchased);
            } else {
                /* Saving to the same wishlist. */
                $storage = &Genie_Driver::singleton($wishlist_target);
                $result = $storage->modify($item_id, $item_name, $item_desc,
                                           $item_quantity, $item_price,
                                           $item_prodid, $item_prodid_type,
                                           $item_vendors, $item_category,
                                           $item_purchased);
            }
        } else {
            $storage = &Genie_Driver::singleton($wishlist_target);
            $result = $storage->add($item_name, $item_desc, $item_quantity,
                                    $item_price, $item_prodid,
                                    $item_prodid_type, $item_vendors,
                                    $item_category, $item_purchased);
        }

        // Check our results.
        if (is_a($result, 'PEAR_Error')) {
            $notification->push(sprintf(_("There was a problem saving the item: %s."),
                                        $result->getMessage()), 'horde.error');
        } else {
            $notification->push(_("The item was saved."), 'horde.success');
        }
    }

    /* Return to the wishlist. */
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
    break;

case GENIE_DELETE_ITEMS:
    /* Delete the item if we're provided with a valid item ID. */
    $item_id = Util::getFormData('item');
    $wishlist_id = Util::getFormData('wishlist');
    if (isset($item_id)) {
        $share = $genie_shares->getShare($wishlist_id);
        if (is_a($share, 'PEAR_Error') ||
            !$share->hasPermission(Auth::getAuth(), PERMS_DELETE)) {
            $item = Genie::getItem($wishlist_id, $item_id);
            $notification->push(sprintf(_("Access denied deleting item %s."),
                                        $item['name']), 'horde.error');
        } else {
            $storage = &Genie_Driver::singleton($wishlist_id);
            $result = $storage->deleteItem($item_id);
            if (is_a($result, 'PEAR_Error')) {
                $notification->push(sprintf(_("There was a problem deleting: %s"),
                                            $result->getMessage()), 'horde.error');
            } else {
                $notification->push(_("Deleted 1 item."), 'horde.success');
            }
        }
    }

    /* Return to the wishlist. */
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
    break;

case GENIE_PURCHASE_ITEMS:
    /* Purchase the item if we're provided with a valid item ID. */
    $item_id = Util::getFormData('item');
    $wishlist_id = Util::getFormData('wishlist');
    if (isset($item_id)) {
        $share = $genie_shares->getShare($wishlist_id);
        $item = Genie::getItem($wishlist_id, $item_id);
        if (is_a($share, 'PEAR_Error')) {
            $notification->push(sprintf(_("Error accessing wishlist '%s': %s"),
                                        $wishlist_id,
                                        $share->getMessage()), 'horde.error');
        } elseif (!$share->hasPermission(Auth::getAuth(), PERMS_EDIT)) {
            $url = Util::addParameter('purchase.php', array('wishlist' => $wishlist_id,
                                                            'item' => $item_id));
            header('Location: ' . Horde::applicationUrl($url, true));
            exit;
        } else {
            $storage = &Genie_Driver::singleton($wishlist_id);
            $result = $storage->modify($item_id, $item['name'], $item['desc'],
                                       $item['quantity'], $item['price'],
                                       $item['prodid'], $item['prodid_type'],
                                       $item['vendors'], $item['category'], 1,
                                       time(), Genie::getUserEmail());
            if (is_a($result, 'PEAR_Error')) {
                $notification->push(sprintf(_("There was a problem purchasing %s: %s"),
                                            $item['name'],
                                            $result->getMessage()), 'horde.error');
            } else {
                $notification->push(sprintf(_("%s is now marked as purchased by you. If this is not correct, please edit the item to revert the change."),
                                            $item['name']), 'horde.success');
            }
        }
    }

    /* Fall through to return to the item list. */
default:
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
}

$wishlists = Genie::listWishlists(false, PERMS_EDIT);
require GENIE_TEMPLATES . '/common-header.inc';
require GENIE_TEMPLATES . '/menu.inc';
require GENIE_TEMPLATES . '/item/item.inc';
require $registry->get('templates', 'horde') . '/common-footer.inc';
