<?php
/**
 * $Horde: genie/list.php,v 1.38 2005/01/03 14:34:50 jan Exp $
 *
 * Copyright 2003-2005 Chuck Hagenbuch <chuck@horde.org>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */

@define('GENIE_BASE', dirname(__FILE__));
require_once GENIE_BASE . '/lib/base.php';
require_once 'Horde/Template.php';
require_once 'Horde/Variables.php';
require_once 'Horde/Text/Filter.php';

$vars = &Variables::getDefaultVariables();

/* Get the current action ID. */
$actionID = Util::getFormData('actionID');

/* Sort out the sorting values and item filtering. */
if (($sortby = Util::getFormData('sortby')) !== null) {
    $prefs->setValue('sortby', $sortby);
}
if (($sortdir = Util::getFormData('sortdir')) !== null) {
    $prefs->setValue('sortdir', $sortdir);
}
if ($vars->exists('show_purchased')) {
    $prefs->setValue('show_purchased', $vars->get('show_purchased'));
} else {
    $vars->set('show_purchased', $prefs->getValue('show_purchased'));
}

/* Get the full, sorted wishlist. */
$items = Genie::listItems($prefs->getValue('sortby'),
                          $prefs->getValue('sortdir'));

/* Page variables. */
$title = _("Wishlist Items");

switch ($actionID) {
case GENIE_SEARCH_ITEMS:
    /* Get the search parameters. */
    $pattern = Util::getFormData('search_pattern');
    $search_name = (Util::getFormData('search_name') == 'on');
    $search_desc = (Util::getFormData('search_desc') == 'on');

    if (!empty($pattern) && ($search_name || $search_desc)) {
        $pattern = '/' . preg_quote($pattern, '/') . '/i';
        $search_results = array();
        foreach ($items as $item_id => $item) {
            if (($search_name && preg_match($pattern, $item['name'])) ||
                ($search_desc && preg_match($pattern, $item['desc']))) {
                $search_results[$item_id] = $item;
            }
        }

        /* Reassign $items to the search result. */
        $items = $search_results;
        $title = _("Wishlist Search Results");
    }
    break;
}

/* Fill out the $items hash for templating. */
$seen = array();
$descriptions = array();
foreach ($items as $item_id => $item) {
    if (empty($seen[$item['wishlist_id']])) {
        $seen[$item['wishlist_id']] = true;
        $share = $genie_shares->getShare($item['wishlist_id']);
        if (!is_a($share, 'PEAR_Error') && $share->get('desc')) {
            $descriptions[$share->get('name')] = $share->get('desc');
        }
    }

    $tstyle = '';
    if (!empty($item['purchased'])) {
        $style = 'purchased';
        $tstyle = 'linethrough';
    } else {
        $style = 'text';
    }
    $items[$item_id]['style'] = $style;
    $items[$item_id]['tstyle'] = $tstyle;

    $viewurl = Util::addParameter('view.php', 'item', $item['item_id']);
    $viewurl = Util::addParameter($viewurl, 'wishlist', $item['wishlist_id']);

    $itemurl = Util::addParameter('item.php', 'item', $item['item_id']);
    $itemurl = Util::addParameter($itemurl, 'wishlist', $item['wishlist_id']);

    $owner = $item['wishlist_id'];
    $items[$item_id]['purchase'] = '&nbsp';
    $share = $genie_shares->getShare($item['wishlist_id']);
    if (!is_a($share, 'PEAR_Error')) {
        $owner = $share->get('name');

        if (empty($item['purchased'])) {
            if ($share->hasPermission(Auth::getAuth(), PERMS_EDIT)) {
                $items[$item_id]['purchase'] = Horde::link(Horde::applicationUrl(Util::addParameter($itemurl, 'actionID', GENIE_PURCHASE_ITEMS)), _("Purchase Item"), 'widget') .
                    Horde::img('purchase.png', _("Purchase")) . '</a>';
            } else {
                $items[$item_id]['purchase'] = Horde::link(Horde::applicationUrl(Util::addParameter('purchase.php', array('item' => $item['item_id'], 'wishlist' => $item['wishlist_id']))), _("Purchase Item"), 'widget') .
                    Horde::img('purchase.png', _("Purchase")) . '</a>';
            }
        }
    }

    $items[$item_id]['owner'] = $owner;
    $items[$item_id]['desc'] = Text_Filter::filter($item['desc'], 'linkurls', array('callback' => 'Horde::externalUrl'));
    $items[$item_id]['category'] = htmlspecialchars($item['category'] ? $item['category'] : _("Unfiled"));
    $items[$item_id]['view'] = Horde::link(Horde::applicationUrl($viewurl), _("Show Item"), $tstyle) . (!empty($item['name']) ? Text_Filter::filter((htmlspecialchars($item['name'])), 'linkurls', array('callback' => 'Horde::externalUrl')) : _("[Show Item]")) . '</a>';
}

require GENIE_TEMPLATES . '/common-header.inc';
require GENIE_TEMPLATES . '/menu.inc';

if (count($descriptions)) {
    require GENIE_TEMPLATES . '/common-descriptions.inc';
}

if (!$prefs->isLocked('show_purchased')) {
    require_once 'Horde/UI/Tabs.php';
    $listurl = Horde::applicationUrl('list.php');
    $tabs = &new Horde_UI_Tabs('show_purchased', $vars);
    $tabs->addTab(_("All items"), $listurl, 1);
    $tabs->addTab(_("Unpurchased items"), $listurl, 0);
    $tabs->addTab(_("Purchased items"), $listurl, 2);
    echo $tabs->render($prefs->getValue('show_purchased'));
}

require GENIE_TEMPLATES . '/list/header.inc';

if (count($items)) {
    $sortby = $prefs->getValue('sortby');
    $sortdir = $prefs->getValue('sortdir');
    require GENIE_TEMPLATES . '/list/item_headers.inc';

    $template = &new Horde_Template();
    $template->set('items', $items);
    echo $template->fetch(GENIE_TEMPLATES . '/list/items.html');

    require GENIE_TEMPLATES . '/list/item_footers.inc';
} else {
    require GENIE_TEMPLATES . '/list/empty.inc';
}

require GENIE_TEMPLATES . '/list/footer.inc';
require $registry->get('templates', 'horde') . '/common-footer.inc';
