<?php
/**
 * $Horde: genie/purchase.php,v 1.7 2005/01/03 14:34:50 jan Exp $
 *
 * Copyright 2003-2005 Chuck Hagenbuch <chuck@horde.org>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */

define('GENIE_BASE', dirname(__FILE__));
require_once GENIE_BASE . '/lib/base.php';

$item_id = Util::getFormData('item');
$wishlist_id = Util::getFormData('wishlist');

if ($item_id === null || $wishlist_id === null) {
    header('Location: ' . Horde::applicationUrl('list.php'));
    exit;
}

/* Get the item's wishlist object. */
$share = $genie_shares->getShare($wishlist_id);
if (is_a($share, 'PEAR_Error')) {
    $notification->push(sprintf(_("There was an error accessing the item: %s"), $share->getMessage()), 'horde.error');
    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
}

/* Get the item to be purchased. */
$item = Genie::getItem($wishlist_id, $item_id);
if (!$item) {
    $notification->push(_("Item not found."), 'horde.error');
    header('Location: ' . Horde::applicationUrl('list.php'));
    exit;
}

/* Make sure it's not already purchased. */
if (!empty($item['purchased'])) {
    $notification->push(sprintf(_("%s has already been purchased."), $item['name']), 'horde.error');
    header('Location: ' . Horde::applicationUrl('list.php'));
    exit;
}

/* Run through the action handlers. */
$actionID = Util::getFormData('actionID');
switch ($actionID) {
case GENIE_PURCHASE_ITEMS:
    /* Make sure we got a name and email. */
    $email = Util::getFormData('email');
    if (!$email) {
        $notification->push(_("Please enter a valid email address."), 'horde.warning');
        break;
    }

    /* Purchase the item. */
    $storage = &Genie_Driver::singleton($wishlist_id);
    $result = $storage->modify($item_id, $item['name'], $item['desc'], $item['quantity'],
                               $item['price'], $item['prodid'], $item['prodid_type'],
                               $item['vendors'], $item['category'], 1, time(), $email);
    if (is_a($result, 'PEAR_Error')) {
        $notification->push(sprintf(_("There was a problem purchasing %s: %s"), $item['name'], $result->getMessage()), 'horde.error');
    } else {
        $notification->push(sprintf(_("%s is now marked as purchased by you. If you are unable to purchase this item, please make sure you come back to release the item so someone else can buy it."), $item['name']), 'horde.success');
    }

    header('Location: ' . Horde::applicationUrl('list.php'));
    exit;
}

$wishlists = Genie::listWishlists();
$title = sprintf(_("Purchase %s"), $item['name']);
$notification->push('document.purchase.email.focus();', 'javascript');
require GENIE_TEMPLATES . '/common-header.inc';
require GENIE_TEMPLATES . '/menu.inc';

/* Show the wishlist description if there is one. */
if ($share->get('desc')) {
    $descriptions = array($share->get('name') => $share->get('desc'));
    require GENIE_TEMPLATES . '/common-descriptions.inc';
}

/* Get the user's identity, if present. */
if (Auth::getAuth()) {
    $email = Genie::getUserEmail();
} else {
    $email = '';
}

require GENIE_TEMPLATES . '/purchase/purchase.inc';
require $registry->get('templates', 'horde') . '/common-footer.inc';
