<?php
/**
 * $Horde: genie/wishlists.php,v 1.26 2005/01/03 14:34:50 jan Exp $
 *
 * Copyright 2003-2005 Chuck Hagenbuch <chuck@horde.org>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */

@define('GENIE_BASE', dirname(__FILE__));
require_once GENIE_BASE . '/lib/base.php';

/* Exit if this isn't an authenticated user. */
if (!Auth::getAuth()) {
    require GENIE_BASE . '/list.php';
    exit;
}

$to_edit = null;
$onlynew = 0;
$actionID = Util::getFormData('actionID');

/* Run through the action handlers. */
switch ($actionID) {
case 'save':
    $to_edit = Util::getFormData('edit_share');
    $id = Util::getFormData('id');
    if (empty($id)) {
        $notification->push(_("Wishlists must have a name."), 'horde.error');
        break;
    }

    $wishlist = '';
    if (!isset($to_edit) || $to_edit == '') {
        /* Create New Share */
        $wishlist = $genie_shares->newShare(md5(microtime()));
        $wishlist->set('name', $id);
        $wishlist->set('desc', Util::getFormData('description', ''));
        $result = $genie_shares->addShare($wishlist);

        if (is_a($result, 'PEAR_Error')) {
            $notification->push(sprintf(_("The wishlist \"%s\" couldn't be created: %s"), $id, $result->getMessage()), 'horde.error');
        } else {
            /* Set initial permissions. */
            $wishlist_id = $wishlist->getName();
            $wishlist = &$genie_shares->getShare($wishlist_id);
            $perm = &$wishlist->getPermission();
            $perm->addGuestPermission(PERMS_SHOW | PERMS_READ, false);
            $perm->addDefaultPermission(PERMS_SHOW | PERMS_READ, false);
            $wishlist->setPermission($perm);
            $wishlist->save();

            $notification->push(sprintf(_("The wishlist \"%s\" has been created."), $id), 'horde.success');
        }
    } else {
        $wishlist = &$genie_shares->getShare($to_edit);
        $wishlist->set('name', $id);
        $wishlist->set('desc', Util::getFormData('description', ''));
        $wishlist->save();

        $notification->push(sprintf(_("The wishlist \"%s\" has been saved."), $id), 'horde.success');
    }

    unset($to_edit);
    break;

case 'delete':
    $to_delete = Util::getFormData('edit_share');
    $id = Util::getFormData('id');

    if (isset($to_delete)) {
        $share = $genie_shares->getShare($to_delete);

        /* Delete the wishlist. */
        require_once GENIE_BASE . '/lib/Driver.php';
        $storage = &Genie_Driver::singleton($to_delete);
        $result = $storage->deleteAll();
        if (is_a($result, 'PEAR_Error')) {
            $notification->push(sprintf(_("Unable to delete \"%s\": %s"), $share->get('name'), $result->getMessage()), 'horde.error');
        } else {
            /* Remove share and all groups/permissions. */
            $genie_shares->removeShare($share);
            $notification->push(sprintf(_("The wishlist \"%s\" has been deleted."), $share->get('name')), 'horde.success');
        }
    } else {
        $notification->push(_("You must select a wishlist to be deleted."), 'horde.warning');
    }

    /* Make sure we still have at least one wishlist. */
    if (count(Genie::listWishlists(true)) == 0) {
        /* If this share doesn't exist then create it */
        if (!$genie_shares->exists(Auth::getAuth())) {
            require_once 'Horde/Identity.php';
            $identity = &Identity::singleton();
            $name = $identity->getValue('fullname');
            if (trim($name) == '') {
                $name = Auth::removeHook(Auth::getAuth());
            }
            $share = $genie_shares->newShare(Auth::getAuth());
            $share->set('name', sprintf(_("%s's Wishlist"), $name));
            $genie_shares->addShare($share);
        }
    }
    break;
}

/* Personal Wishlists */
$personal_wishlists = Genie::listWishlists(true);

Horde::addScriptFile('popup.js', 'horde', true);
$title = _("Wishlists");
require GENIE_TEMPLATES . '/common-header.inc';
require GENIE_TEMPLATES . '/menu.inc';
require GENIE_TEMPLATES . '/wishlists/wishlists.inc';
require $registry->get('templates', 'horde') . '/common-footer.inc';
